import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';
import {
  AuthGuard,
  NotFoundComponent,
  PortalContainerComponent,
  PortalContainerNoSidenavComponent,
} from '@cima/commons';

const routes: Routes = [
  {
    path: '',
    redirectTo: 'dashboard',
    pathMatch: 'full',
  },

  {
    path: '',
    component: PortalContainerComponent,
    canActivate: [AuthGuard],
    children: [
      {
        path: 'dashboard',
        loadChildren: () =>
          import('@cima/dashboard').then((m) => m.DashboardModule),
      },
      {
        path: 'credits',
        loadChildren: () =>
          import('./credits/credits.module').then((m) => m.CreditsModule),
      },
      {
        path: 'admin',
        loadChildren: () =>
          import('@cima/admin').then((m) => m.CimaAdminModule),
      },
      {
        path: 'kumale',
        loadChildren: () =>
          import('@cima/kumale').then((m) => m.CimaKumaleModule),
      },
    ],
  },

  {
    path: '',
    component: PortalContainerNoSidenavComponent,
    canActivate: [AuthGuard],
    children: [
      // {
      //   path: 'kumale',
      //   loadChildren: () =>
      //     import('@cima/kumale').then((m) => m.CimaKumaleModule),
      // },
    ],
  },

  {
    path: '404',
    component: NotFoundComponent,
  },

  {
    path: '**',
    redirectTo: '',
  },
];

@NgModule({
  imports: [RouterModule.forRoot(routes, { enableTracing: false })],
  exports: [RouterModule],
})
export class AppRoutingModule {}
