import { APP_INITIALIZER, LOCALE_ID, NgModule } from '@angular/core';
import { ServiceWorkerModule } from '@angular/service-worker';
import { registerLocaleData } from '@angular/common';
import { HttpClient, HTTP_INTERCEPTORS } from '@angular/common/http';

import { OAuthModuleConfig, OAuthStorage } from 'angular-oauth2-oidc';

import localeIt from '@angular/common/locales/it';
import localeItExtra from '@angular/common/locales/extra/it';

import {TranslateModule} from "@ngx-translate/core";

registerLocaleData(localeIt, 'it-IT', localeItExtra);

import {
  CimaCommonsModule,
  CimaConfigService,
  PortalService,
  SkinService,
  authConfigFactory,
  AuthGuard,
  AuthService,
  getAuthConfig,
  storageFactory,
} from '@cima/commons';
import { WidgetCacheInterceptor } from '@cima/dashboard';

import { environment } from '../environments/environment';

import { AppRoutingModule } from './app-routing.module';

import { CoreModule } from './core/core.module';
import { SharedModule } from './shared/shared.module';

import { AppComponent } from './app.component';

@NgModule({
  declarations: [AppComponent],
  imports: [
    CoreModule.forRoot(environment),
    AppRoutingModule,
    SharedModule,
    CimaCommonsModule.forRoot(environment),
    ServiceWorkerModule.register('ngsw-worker.js', {
      enabled: environment.production,
      // Register the ServiceWorker as soon as the app is stable
      // or after 30 seconds (whichever comes first).
      registrationStrategy: 'registerWhenStable:30000',
    }),
    TranslateModule.forRoot({
      defaultLanguage: 'en',
    })
  ],
  providers: [
    AuthGuard,
    SkinService,
    {
      provide: OAuthModuleConfig,
      useFactory: authConfigFactory,
      deps: [CimaConfigService],
    },
    { provide: OAuthStorage, useFactory: storageFactory },
    {
      provide: APP_INITIALIZER,
      useFactory: getAuthConfig,
      deps: [HttpClient, AuthService, CimaConfigService, SkinService],
      multi: true,
    },
    {
      provide: LOCALE_ID,
      deps: [PortalService],
      useFactory: (portalService: PortalService) => portalService.getLanguage(),
    },
    {
      provide: HTTP_INTERCEPTORS,
      useClass: WidgetCacheInterceptor,
      multi: true,
    },
  ],
  bootstrap: [AppComponent],
})
export class AppModule {}
